@@ -186,13 +186,12 @@ impl Screen {
                                 self.search_forward();
                             } else if c == '?' {
                                 self.search_backward();
-                            } else if c == 'h' {
-                                self.help();
                             } else {
                                 self.prefix_jump_to(c.to_string());
                             }
                         }
                     }
+                    Action::Help => self.help(),
                     Action::UnselectRet => return self.unselect().is_some(),
                     Action::ScrollUp => self.scroll_up(),
                     Action::ScrollDown => self.scroll_down(),
@@ -694,12 +693,16 @@ impl Screen {
             let node = self.format_node(&raw_node);
             let width = 1 + (3 * depth as u16) + node.content.len() as u16;
             let mut ret = vec![width];
+            let hide_stricken = self.with_node(node_id, |n| n.hide_stricken).unwrap();
             if !node.collapsed {
                 for &child in &node.children {
-                    // ASSUMES node.children are all valid
-                    let mut child_widths = self.drawable_subtree_widths(child, depth + 1)
-                        .unwrap();
-                    ret.append(&mut child_widths);
+                    let stricken = self.with_node(child, |c| c.stricken).unwrap();
+                    if !(hide_stricken && stricken) {
+                        // ASSUMES node.children are all valid
+                        let mut child_widths = self.drawable_subtree_widths(child, depth + 1)
+                            .unwrap();
+                        ret.append(&mut child_widths);
+                    }
                 }
             }
             Some(ret)
